@@ -2024,7 +2024,9 @@ sysprof_document_symbolize_traceable (SysprofDocument           *self,
 
       symbols[n_symbolized] = _sysprof_document_symbols_lookup (self->symbols, process_info, last_context, addresses[i]);
 
-      if (symbols[n_symbolized] != NULL)
+      if (symbols[n_symbolized] != NULL &&
+          /* if we symbolized recursively, skip this one */
+          (n_symbolized == 0 || symbols[n_symbolized-1] != symbols[n_symbolized]))
         n_symbolized++;
 
       if (sysprof_address_is_context_switch (addresses[i], &context))
@@ -2585,7 +2587,11 @@ sysprof_document_serialize_symbols_fiber (gpointer user_data)
                                               process_info->pid);
     }
 
-  g_array_sort (packed_symbols, sort_symbols_for_bsearch);
+  gtk_tim_sort (packed_symbols->data,
+                packed_symbols->len,
+                sizeof (SysprofPackedSymbol),
+                (GCompareDataFunc)sort_symbols_for_bsearch,
+                NULL);
   g_array_append_val (packed_symbols, empty_symbol);
 
   packed_len = sizeof (SysprofPackedSymbol) * packed_symbols->len;
